==> hs-syb-0.3.3.tbz: lib/ghc-7.0.4/cabal/syb-0.3.3/register.sh <==
#!/bin/sh
echo 'name: syb
version: 0.3.3
id: syb-0.3.3-43363d15978052669a36ccb62324e276

license: BSD3
copyright:
maintainer: generics@haskell.org
stability: provisional
homepage: http://www.cs.uu.nl/wiki/GenericProgramming/SYB
package-url:
description: This package contains the generics system described in the
             /Scrap Your Boilerplate/ papers (see
             <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
             It defines the @Data@ class of types permitting folding and unfolding
             of constructor applications, instances of this class for primitive
             types, and a variety of traversals.
category: Generics
author: Ralf Lammel, Simon Peyton Jones
exposed: True
exposed-modules: Data.Generics Data.Generics.Basics
                 Data.Generics.Instances Data.Generics.Aliases Data.Generics.Schemes
                 Data.Generics.Text Data.Generics.Twins Data.Generics.Builders
                 Generics.SYB Generics.SYB.Basics Generics.SYB.Instances
                 Generics.SYB.Aliases Generics.SYB.Schemes Generics.SYB.Text
                 Generics.SYB.Twins Generics.SYB.Builders
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/syb-0.3.3
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/syb-0.3.3
              /usr/local/lib
hs-libraries: HSsyb-0.3.3
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/syb-0.3.3/html/syb.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/syb-0.3.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-syb-0.3.6.1_1.tbz: lib/ghc-7.4.1/cabal/syb-0.3.6.1/register.sh <==
#!/bin/sh
echo 'name: syb
version: 0.3.6.1
id: syb-0.3.6.1-ad5889c79a555efaeb0cf987ce0538b6

license: BSD3
copyright:
maintainer: generics@haskell.org
stability: provisional
homepage: http://www.cs.uu.nl/wiki/GenericProgramming/SYB
package-url:
synopsis: Scrap Your Boilerplate
description: This package contains the generics system described in the
             /Scrap Your Boilerplate/ papers (see
             <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
             It defines the @Data@ class of types permitting folding and unfolding
             of constructor applications, instances of this class for primitive
             types, and a variety of traversals.
category: Generics
author: Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
exposed: True
exposed-modules: Data.Generics Data.Generics.Basics
                 Data.Generics.Instances Data.Generics.Aliases Data.Generics.Schemes
                 Data.Generics.Text Data.Generics.Twins Data.Generics.Builders
                 Generics.SYB Generics.SYB.Basics Generics.SYB.Instances
                 Generics.SYB.Aliases Generics.SYB.Schemes Generics.SYB.Text
                 Generics.SYB.Twins Generics.SYB.Builders
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/syb-0.3.6.1
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/syb-0.3.6.1
              /usr/local/lib
hs-libraries: HSsyb-0.3.6.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/syb-0.3.6.1/html/syb.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/syb-0.3.6.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
